@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,21 +27,40 @@
 
 
 
+
 from .fetchers import NUL2DomainsFetcher
 
 
 from .fetchers import NUL2DomainTemplatesFetcher
 
 
+from .fetchers import NUL4ServicesFetcher
+
+
+from .fetchers import NUL4ServiceGroupsFetcher
+
+
 from .fetchers import NUL7applicationsignaturesFetcher
 
 
+from .fetchers import NUSaaSApplicationGroupsFetcher
+
+
+from .fetchers import NUSaaSApplicationTypesFetcher
+
+
+from .fetchers import NUCaptivePortalProfilesFetcher
+
+
 from .fetchers import NURateLimitersFetcher
 
 
 from .fetchers import NUGatewaysFetcher
 
 
+from .fetchers import NUGatewaysLocationsFetcher
+
+
 from .fetchers import NUGatewayTemplatesFetcher
 
 
@@ -51,16 +70,25 @@ from .fetchers import NUPATNATPoolsFetcher
 from .fetchers import NULDAPConfigurationsFetcher
 
 
+from .fetchers import NUWebCategoriesFetcher
+
+
+from .fetchers import NUWebDomainNamesFetcher
+
+
 from .fetchers import NURedundancyGroupsFetcher
 
 
+from .fetchers import NUDeploymentFailuresFetcher
+
+
 from .fetchers import NUPerformanceMonitorsFetcher
 
 
 from .fetchers import NUMetadatasFetcher
 
 
-from .fetchers import NUMetadataTagsFetcher
+from .fetchers import NUNetconfProfilesFetcher
 
 
 from .fetchers import NUNetworkMacroGroupsFetcher
@@ -117,6 +145,18 @@ from .fetchers import NUGlobalMetadatasFetcher
 from .fetchers import NUVMsFetcher
 
 
+from .fetchers import NUVNFsFetcher
+
+
+from .fetchers import NUVNFMetadatasFetcher
+
+
+from .fetchers import NUVNFThresholdPoliciesFetcher
+
+
+from .fetchers import NUIngressQOSPoliciesFetcher
+
+
 from .fetchers import NUEnterpriseNetworksFetcher
 
 
@@ -126,6 +166,12 @@ from .fetchers import NUEnterpriseSecuritiesFetcher
 from .fetchers import NUJobsFetcher
 
 
+from .fetchers import NUPolicyGroupCategoriesFetcher
+
+
+from .fetchers import NUPolicyObjectGroupsFetcher
+
+
 from .fetchers import NUDomainsFetcher
 
 
@@ -135,6 +181,9 @@ from .fetchers import NUDomainTemplatesFetcher
 from .fetchers import NUContainersFetcher
 
 
+from .fetchers import NUCOSRemarkingPolicyTablesFetcher
+
+
 from .fetchers import NURoutingPoliciesFetcher
 
 
@@ -144,24 +193,33 @@ from .fetchers import NUApplicationsFetcher
 from .fetchers import NUApplicationperformancemanagementsFetcher
 
 
-from .fetchers import NUApplicationServicesFetcher
-
-
 from .fetchers import NUGroupsFetcher
 
 
 from .fetchers import NUGroupKeyEncryptionProfilesFetcher
 
 
+from .fetchers import NUTrunksFetcher
+
+
 from .fetchers import NUDSCPForwardingClassTablesFetcher
 
 
+from .fetchers import NUDSCPRemarkingPolicyTablesFetcher
+
+
 from .fetchers import NUUsersFetcher
 
 
 from .fetchers import NUNSGatewaysFetcher
 
 
+from .fetchers import NUNSGatewaysCountsFetcher
+
+
+from .fetchers import NUNSGatewaySummariesFetcher
+
+
 from .fetchers import NUNSGatewayTemplatesFetcher
 
 
@@ -183,10 +241,10 @@ from .fetchers import NUAvatarsFetcher
 from .fetchers import NUEventLogsFetcher
 
 
-from .fetchers import NUExternalAppServicesFetcher
+from .fetchers import NUOverlayManagementProfilesFetcher
 
 
-from .fetchers import NUExternalServicesFetcher
+from .fetchers import NUSyslogDestinationsFetcher
 
 from bambou import NURESTObject
 
@@ -206,14 +264,22 @@ class NUEnterprise(NURESTObject):
     
     CONST_ENCRYPTION_MANAGEMENT_MODE_MANAGED = "MANAGED"
     
+    CONST_FLOW_COLLECTION_ENABLED_ENABLED = "ENABLED"
+    
     CONST_AVATAR_TYPE_COMPUTEDURL = "COMPUTEDURL"
     
+    CONST_ALLOWED_FORWARDING_MODE_LOCAL_AND_REMOTE = "LOCAL_AND_REMOTE"
+    
+    CONST_ALLOWED_FORWARDING_MODE_DISABLED = "DISABLED"
+    
     CONST_ALLOWED_FORWARDING_CLASSES_NONE = "NONE"
     
     CONST_AVATAR_TYPE_BASE64 = "BASE64"
     
     CONST_ENCRYPTION_MANAGEMENT_MODE_DISABLED = "DISABLED"
     
+    CONST_FLOW_COLLECTION_ENABLED_DISABLED = "DISABLED"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_ALLOWED_FORWARDING_CLASSES_D = "D"
@@ -236,6 +302,8 @@ class NUEnterprise(NURESTObject):
     
     CONST_ALLOWED_FORWARDING_CLASSES_H = "H"
     
+    CONST_ALLOWED_FORWARDING_MODE_LOCAL_ONLY = "LOCAL_ONLY"
+    
     
 
     def __init__(self, **kwargs):
@@ -259,23 +327,30 @@ class NUEnterprise(NURESTObject):
         self._ldap_enabled = None
         self._bgp_enabled = None
         self._dhcp_lease_interval = None
+        self._vnf_management_enabled = None
         self._name = None
         self._last_updated_by = None
+        self._web_filter_enabled = None
         self._receive_multi_cast_list_id = None
         self._send_multi_cast_list_id = None
         self._description = None
+        self._shared_enterprise = None
         self._dictionary_version = None
+        self._virtual_firewall_rules_enabled = None
         self._allow_advanced_qos_configuration = None
         self._allow_gateway_management = None
         self._allow_trusted_forwarding_class = None
         self._allowed_forwarding_classes = None
+        self._allowed_forwarding_mode = None
         self._floating_ips_quota = None
         self._floating_ips_used = None
+        self._flow_collection_enabled = None
         self._enable_application_performance_management = None
         self._encryption_management_mode = None
         self._enterprise_profile_id = None
         self._entity_scope = None
         self._local_as = None
+        self._use_global_mac = None
         self._associated_enterprise_security_id = None
         self._associated_group_key_encryption_profile_id = None
         self._associated_key_server_monitor_id = None
@@ -288,23 +363,30 @@ class NUEnterprise(NURESTObject):
         self.expose_attribute(local_name="ldap_enabled", remote_name="LDAPEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="bgp_enabled", remote_name="BGPEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dhcp_lease_interval", remote_name="DHCPLeaseInterval", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="vnf_management_enabled", remote_name="VNFManagementEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_enabled", remote_name="webFilterEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="receive_multi_cast_list_id", remote_name="receiveMultiCastListID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="send_multi_cast_list_id", remote_name="sendMultiCastListID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="shared_enterprise", remote_name="sharedEnterprise", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dictionary_version", remote_name="dictionaryVersion", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="virtual_firewall_rules_enabled", remote_name="virtualFirewallRulesEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_advanced_qos_configuration", remote_name="allowAdvancedQOSConfiguration", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_gateway_management", remote_name="allowGatewayManagement", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_trusted_forwarding_class", remote_name="allowTrustedForwardingClass", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_forwarding_classes", remote_name="allowedForwardingClasses", attribute_type=list, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
+        self.expose_attribute(local_name="allowed_forwarding_mode", remote_name="allowedForwardingMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'LOCAL_AND_REMOTE', u'LOCAL_ONLY'])
         self.expose_attribute(local_name="floating_ips_quota", remote_name="floatingIPsQuota", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="floating_ips_used", remote_name="floatingIPsUsed", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="flow_collection_enabled", remote_name="flowCollectionEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="enable_application_performance_management", remote_name="enableApplicationPerformanceManagement", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption_management_mode", remote_name="encryptionManagementMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'MANAGED'])
         self.expose_attribute(local_name="enterprise_profile_id", remote_name="enterpriseProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="local_as", remote_name="localAS", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_enterprise_security_id", remote_name="associatedEnterpriseSecurityID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_group_key_encryption_profile_id", remote_name="associatedGroupKeyEncryptionProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_key_server_monitor_id", remote_name="associatedKeyServerMonitorID", attribute_type=str, is_required=False, is_unique=False)
@@ -323,15 +405,33 @@ class NUEnterprise(NURESTObject):
         self.l2_domain_templates = NUL2DomainTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.l4_services = NUL4ServicesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.l4_service_groups = NUL4ServiceGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.l7applicationsignatures = NUL7applicationsignaturesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.saa_s_application_groups = NUSaaSApplicationGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.saa_s_application_types = NUSaaSApplicationTypesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.captive_portal_profiles = NUCaptivePortalProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.rate_limiters = NURateLimitersFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.gateways = NUGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.gateways_locations = NUGatewaysLocationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.gateway_templates = NUGatewayTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -341,16 +441,25 @@ class NUEnterprise(NURESTObject):
         self.ldap_configurations = NULDAPConfigurationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.web_categories = NUWebCategoriesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.web_domain_names = NUWebDomainNamesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.redundancy_groups = NURedundancyGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.deployment_failures = NUDeploymentFailuresFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.performance_monitors = NUPerformanceMonitorsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.metadata_tags = NUMetadataTagsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.netconf_profiles = NUNetconfProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.network_macro_groups = NUNetworkMacroGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
@@ -407,6 +516,18 @@ class NUEnterprise(NURESTObject):
         self.vms = NUVMsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.vnfs = NUVNFsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.vnf_metadatas = NUVNFMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.vnf_threshold_policies = NUVNFThresholdPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ingress_qos_policies = NUIngressQOSPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.enterprise_networks = NUEnterpriseNetworksFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -416,6 +537,12 @@ class NUEnterprise(NURESTObject):
         self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.policy_group_categories = NUPolicyGroupCategoriesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.policy_object_groups = NUPolicyObjectGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.domains = NUDomainsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -425,6 +552,9 @@ class NUEnterprise(NURESTObject):
         self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.cos_remarking_policy_tables = NUCOSRemarkingPolicyTablesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.routing_policies = NURoutingPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -434,24 +564,33 @@ class NUEnterprise(NURESTObject):
         self.applicationperformancemanagements = NUApplicationperformancemanagementsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.application_services = NUApplicationServicesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.groups = NUGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.group_key_encryption_profiles = NUGroupKeyEncryptionProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.trunks = NUTrunksFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.dscp_forwarding_class_tables = NUDSCPForwardingClassTablesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.dscp_remarking_policy_tables = NUDSCPRemarkingPolicyTablesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.users = NUUsersFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.ns_gateways = NUNSGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.ns_gateways_counts = NUNSGatewaysCountsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ns_gateway_summaries = NUNSGatewaySummariesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.ns_gateway_templates = NUNSGatewayTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -473,10 +612,10 @@ class NUEnterprise(NURESTObject):
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.external_app_services = NUExternalAppServicesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.overlay_management_profiles = NUOverlayManagementProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.external_services = NUExternalServicesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.syslog_destinations = NUSyslogDestinationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
         self._compute_args(**kwargs)
@@ -542,7 +681,7 @@ class NUEnterprise(NURESTObject):
         """ Get bgp_enabled value.
 
             Notes:
-                Read only flag to display if BGP is enabled for this enterprise
+                Read-only flag to display if BGP is enabled for this enterprise
 
                 
                 This attribute is named `BGPEnabled` in VSD API.
@@ -555,7 +694,7 @@ class NUEnterprise(NURESTObject):
         """ Set bgp_enabled value.
 
             Notes:
-                Read only flag to display if BGP is enabled for this enterprise
+                Read-only flag to display if BGP is enabled for this enterprise
 
                 
                 This attribute is named `BGPEnabled` in VSD API.
@@ -591,12 +730,39 @@ class NUEnterprise(NURESTObject):
         self._dhcp_lease_interval = value
 
     
+    @property
+    def vnf_management_enabled(self):
+        """ Get vnf_management_enabled value.
+
+            Notes:
+                Read-only flag to display if VNF management is enabled for this enterprise
+
+                
+                This attribute is named `VNFManagementEnabled` in VSD API.
+                
+        """
+        return self._vnf_management_enabled
+
+    @vnf_management_enabled.setter
+    def vnf_management_enabled(self, value):
+        """ Set vnf_management_enabled value.
+
+            Notes:
+                Read-only flag to display if VNF management is enabled for this enterprise
+
+                
+                This attribute is named `VNFManagementEnabled` in VSD API.
+                
+        """
+        self._vnf_management_enabled = value
+
+    
     @property
     def name(self):
         """ Get name value.
 
             Notes:
-                The unique name of the enterprise. Valid characters are alphabets, numbers, space and hyphen( - ).
+                The unique name of the enterprise.
 
                 
         """
@@ -607,7 +773,7 @@ class NUEnterprise(NURESTObject):
         """ Set name value.
 
             Notes:
-                The unique name of the enterprise. Valid characters are alphabets, numbers, space and hyphen( - ).
+                The unique name of the enterprise.
 
                 
         """
@@ -641,12 +807,39 @@ class NUEnterprise(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def web_filter_enabled(self):
+        """ Get web_filter_enabled value.
+
+            Notes:
+                Read only flag to display if Web Filtering is enabled for this enterprise
+
+                
+                This attribute is named `webFilterEnabled` in VSD API.
+                
+        """
+        return self._web_filter_enabled
+
+    @web_filter_enabled.setter
+    def web_filter_enabled(self, value):
+        """ Set web_filter_enabled value.
+
+            Notes:
+                Read only flag to display if Web Filtering is enabled for this enterprise
+
+                
+                This attribute is named `webFilterEnabled` in VSD API.
+                
+        """
+        self._web_filter_enabled = value
+
+    
     @property
     def receive_multi_cast_list_id(self):
         """ Get receive_multi_cast_list_id value.
 
             Notes:
-                Readonly Id of the auto generated receive multicast list associated with this enterprise profile
+                Read-only Id of the auto generated receive multicast list associated with this enterprise profile
 
                 
                 This attribute is named `receiveMultiCastListID` in VSD API.
@@ -659,7 +852,7 @@ class NUEnterprise(NURESTObject):
         """ Set receive_multi_cast_list_id value.
 
             Notes:
-                Readonly Id of the auto generated receive multicast list associated with this enterprise profile
+                Read-only Id of the auto generated receive multicast list associated with this enterprise profile
 
                 
                 This attribute is named `receiveMultiCastListID` in VSD API.
@@ -673,7 +866,7 @@ class NUEnterprise(NURESTObject):
         """ Get send_multi_cast_list_id value.
 
             Notes:
-                Readonly Id of the auto generated send multicast list associated with this enterprise profile
+                Read-only Id of the auto generated send multicast list associated with this enterprise profile
 
                 
                 This attribute is named `sendMultiCastListID` in VSD API.
@@ -686,7 +879,7 @@ class NUEnterprise(NURESTObject):
         """ Set send_multi_cast_list_id value.
 
             Notes:
-                Readonly Id of the auto generated send multicast list associated with this enterprise profile
+                Read-only Id of the auto generated send multicast list associated with this enterprise profile
 
                 
                 This attribute is named `sendMultiCastListID` in VSD API.
@@ -718,6 +911,33 @@ class NUEnterprise(NURESTObject):
         self._description = value
 
     
+    @property
+    def shared_enterprise(self):
+        """ Get shared_enterprise value.
+
+            Notes:
+                This flag indicates whether this is a Shared Infrastructure Enterprise or not. Its a read-only attribute and it cannot be set by anybody.
+
+                
+                This attribute is named `sharedEnterprise` in VSD API.
+                
+        """
+        return self._shared_enterprise
+
+    @shared_enterprise.setter
+    def shared_enterprise(self, value):
+        """ Set shared_enterprise value.
+
+            Notes:
+                This flag indicates whether this is a Shared Infrastructure Enterprise or not. Its a read-only attribute and it cannot be set by anybody.
+
+                
+                This attribute is named `sharedEnterprise` in VSD API.
+                
+        """
+        self._shared_enterprise = value
+
+    
     @property
     def dictionary_version(self):
         """ Get dictionary_version value.
@@ -745,6 +965,33 @@ class NUEnterprise(NURESTObject):
         self._dictionary_version = value
 
     
+    @property
+    def virtual_firewall_rules_enabled(self):
+        """ Get virtual_firewall_rules_enabled value.
+
+            Notes:
+                Read-only flag that indicates if virtual firewall rules are allowed.
+
+                
+                This attribute is named `virtualFirewallRulesEnabled` in VSD API.
+                
+        """
+        return self._virtual_firewall_rules_enabled
+
+    @virtual_firewall_rules_enabled.setter
+    def virtual_firewall_rules_enabled(self, value):
+        """ Set virtual_firewall_rules_enabled value.
+
+            Notes:
+                Read-only flag that indicates if virtual firewall rules are allowed.
+
+                
+                This attribute is named `virtualFirewallRulesEnabled` in VSD API.
+                
+        """
+        self._virtual_firewall_rules_enabled = value
+
+    
     @property
     def allow_advanced_qos_configuration(self):
         """ Get allow_advanced_qos_configuration value.
@@ -853,6 +1100,33 @@ class NUEnterprise(NURESTObject):
         self._allowed_forwarding_classes = value
 
     
+    @property
+    def allowed_forwarding_mode(self):
+        """ Get allowed_forwarding_mode value.
+
+            Notes:
+                Enum to set allowed controller-less mode
+
+                
+                This attribute is named `allowedForwardingMode` in VSD API.
+                
+        """
+        return self._allowed_forwarding_mode
+
+    @allowed_forwarding_mode.setter
+    def allowed_forwarding_mode(self, value):
+        """ Set allowed_forwarding_mode value.
+
+            Notes:
+                Enum to set allowed controller-less mode
+
+                
+                This attribute is named `allowedForwardingMode` in VSD API.
+                
+        """
+        self._allowed_forwarding_mode = value
+
+    
     @property
     def floating_ips_quota(self):
         """ Get floating_ips_quota value.
@@ -907,6 +1181,33 @@ class NUEnterprise(NURESTObject):
         self._floating_ips_used = value
 
     
+    @property
+    def flow_collection_enabled(self):
+        """ Get flow_collection_enabled value.
+
+            Notes:
+                Determines whether or not flow collection is enabled.
+
+                
+                This attribute is named `flowCollectionEnabled` in VSD API.
+                
+        """
+        return self._flow_collection_enabled
+
+    @flow_collection_enabled.setter
+    def flow_collection_enabled(self, value):
+        """ Set flow_collection_enabled value.
+
+            Notes:
+                Determines whether or not flow collection is enabled.
+
+                
+                This attribute is named `flowCollectionEnabled` in VSD API.
+                
+        """
+        self._flow_collection_enabled = value
+
+    
     @property
     def enable_application_performance_management(self):
         """ Get enable_application_performance_management value.
@@ -939,7 +1240,7 @@ class NUEnterprise(NURESTObject):
         """ Get encryption_management_mode value.
 
             Notes:
-                Readonly encryption management mode of the associated profile
+                Read-only encryption management mode of the associated profile
 
                 
                 This attribute is named `encryptionManagementMode` in VSD API.
@@ -952,7 +1253,7 @@ class NUEnterprise(NURESTObject):
         """ Set encryption_management_mode value.
 
             Notes:
-                Readonly encryption management mode of the associated profile
+                Read-only encryption management mode of the associated profile
 
                 
                 This attribute is named `encryptionManagementMode` in VSD API.
@@ -1042,12 +1343,39 @@ class NUEnterprise(NURESTObject):
         self._local_as = value
 
     
+    @property
+    def use_global_mac(self):
+        """ Get use_global_mac value.
+
+            Notes:
+                Determines whether Global Gateway MAC is enabled or not Enterprise level.
+
+                
+                This attribute is named `useGlobalMAC` in VSD API.
+                
+        """
+        return self._use_global_mac
+
+    @use_global_mac.setter
+    def use_global_mac(self, value):
+        """ Set use_global_mac value.
+
+            Notes:
+                Determines whether Global Gateway MAC is enabled or not Enterprise level.
+
+                
+                This attribute is named `useGlobalMAC` in VSD API.
+                
+        """
+        self._use_global_mac = value
+
+    
     @property
     def associated_enterprise_security_id(self):
         """ Get associated_enterprise_security_id value.
 
             Notes:
-                Readonly Id of the associated group key encryption profile
+                Read-only Id of the associated group key encryption profile
 
                 
                 This attribute is named `associatedEnterpriseSecurityID` in VSD API.
@@ -1060,7 +1388,7 @@ class NUEnterprise(NURESTObject):
         """ Set associated_enterprise_security_id value.
 
             Notes:
-                Readonly Id of the associated group key encryption profile
+                Read-only Id of the associated group key encryption profile
 
                 
                 This attribute is named `associatedEnterpriseSecurityID` in VSD API.
@@ -1074,7 +1402,7 @@ class NUEnterprise(NURESTObject):
         """ Get associated_group_key_encryption_profile_id value.
 
             Notes:
-                Readonly Id of the associated group key encryption profile
+                Read-only Id of the associated group key encryption profile
 
                 
                 This attribute is named `associatedGroupKeyEncryptionProfileID` in VSD API.
@@ -1087,7 +1415,7 @@ class NUEnterprise(NURESTObject):
         """ Set associated_group_key_encryption_profile_id value.
 
             Notes:
-                Readonly Id of the associated group key encryption profile
+                Read-only Id of the associated group key encryption profile
 
                 
                 This attribute is named `associatedGroupKeyEncryptionProfileID` in VSD API.
@@ -1101,7 +1429,7 @@ class NUEnterprise(NURESTObject):
         """ Get associated_key_server_monitor_id value.
 
             Notes:
-                Readonly Id of the associated keyserver monitor
+                Read-only Id of the associated keyserver monitor
 
                 
                 This attribute is named `associatedKeyServerMonitorID` in VSD API.
@@ -1114,7 +1442,7 @@ class NUEnterprise(NURESTObject):
         """ Set associated_key_server_monitor_id value.
 
             Notes:
-                Readonly Id of the associated keyserver monitor
+                Read-only Id of the associated keyserver monitor
 
                 
                 This attribute is named `associatedKeyServerMonitorID` in VSD API.
@@ -1128,7 +1456,7 @@ class NUEnterprise(NURESTObject):
         """ Get customer_id value.
 
             Notes:
-                CustomerID that is used by VSC to identify this enterprise. This is a read only attribute.
+                CustomerID that is used by VSC to identify this enterprise. This can be configured by root user.
 
                 
                 This attribute is named `customerID` in VSD API.
@@ -1141,7 +1469,7 @@ class NUEnterprise(NURESTObject):
         """ Set customer_id value.
 
             Notes:
-                CustomerID that is used by VSC to identify this enterprise. This is a read only attribute.
+                CustomerID that is used by VSC to identify this enterprise. This can be configured by root user.
 
                 
                 This attribute is named `customerID` in VSD API.
